import { Observable } from "rxjs";
import { LogLevelDesc } from "@hyperledger/cactus-common";
import { ISocketApiClient } from "@hyperledger/cactus-core-api";
import { DefaultApi, EthContractInvocationWeb3Method, WatchBlocksV1Options, WatchBlocksV1Progress } from "../generated/openapi/typescript-axios";
import { Configuration } from "../generated/openapi/typescript-axios/configuration";
import { ContractAbi } from "web3";
export declare class EthereumApiClientOptions extends Configuration {
    readonly logLevel?: LogLevelDesc;
    readonly wsApiHost?: string;
    readonly wsApiPath?: string;
}
export type EthereumRequestInputWeb3EthMethod = {
    type: "web3Eth";
    command: string;
};
export type EthereumRequestInputWeb3EthContractMethod = {
    type: "web3EthContract";
    command: EthContractInvocationWeb3Method;
    function: string;
    params?: any[];
};
export type EthereumRequestInputContract = {
    abi?: ContractAbi;
    address?: string;
};
export type EthereumRequestInputMethod = EthereumRequestInputWeb3EthMethod | EthereumRequestInputWeb3EthContractMethod;
export type EthereumRequestInputArgs = {
    args?: any[] | Record<string, unknown>;
};
export declare class EthereumApiClient extends DefaultApi implements ISocketApiClient<WatchBlocksV1Progress> {
    readonly options: EthereumApiClientOptions;
    static readonly CLASS_NAME = "EthereumApiClient";
    private readonly log;
    private readonly wsApiHost;
    private readonly wsApiPath;
    get className(): string;
    constructor(options: EthereumApiClientOptions);
    watchBlocksV1(options?: WatchBlocksV1Options): Observable<WatchBlocksV1Progress>;
    /**
     * Immediately sends request to the validator, doesn't report any error or responses.
     * @param contract - contract to execute on the ledger.
     * @param method - function / method to be executed by validator.
     * @param args - arguments.
     * @note Internally, it's just a wrapper around sendSyncRequest, but handles the promise resolution seamlessly.
     * @deprecated Use EthereumApiClient REST calls directly.
     */
    sendAsyncRequest(contract: EthereumRequestInputContract, method: EthereumRequestInputMethod, args: EthereumRequestInputArgs): void;
    private sendWeb3EthRequest;
    private sendWeb3EthContractRequest;
    /**
     * Sends request to be executed on the ledger, watches and reports any error and the response from a ledger.
     * @param contract - contract to execute on the ledger.
     * @param method - function / method specification to be executed by validator.
     * @param args - arguments.
     * @returns Promise that will resolve with response from the ledger, or reject when error occurred.
     * @deprecated Use EthereumApiClient REST calls directly.
     */
    sendSyncRequest(contract: EthereumRequestInputContract, method: EthereumRequestInputMethod, args: EthereumRequestInputArgs): Promise<any>;
}
